@@ -318,8 +318,12 @@ ProcessReturnCode::State ProcessReturnCode::state() const {
 void ProcessReturnCode::enforce(State expected) const {
   State s = state();
   if (s != expected) {
-    throw std::logic_error(to<std::string>(
-        "Bad use of ProcessReturnCode; state is ", s, " expected ", expected));
+    throw std::logic_error(
+        to<std::string>(
+            "Bad use of ProcessReturnCode; state is ",
+            s,
+            " expected ",
+            expected));
   }
 }
 
