@@ -36,10 +36,8 @@ template <template <
     typename,
     typename,
     typename,
-    template <typename>
-    class,
-    class>
-          class Impl>
+    template <typename> class,
+    class> class Impl>
 struct MapFactory {
   template <
       typename KeyType,
