@@ -17,13 +17,13 @@
 #include <folly/Conv.h>
 #include <folly/Portability.h>
 
-#include <folly/coro/AwaitResult.h>
 #include <folly/coro/Baton.h>
 #include <folly/coro/BlockingWait.h>
 #include <folly/coro/Invoke.h>
 #include <folly/coro/Mutex.h>
 #include <folly/coro/SharedMutex.h>
 #include <folly/coro/Task.h>
+#include <folly/coro/ValueOrError.h>
 #include <folly/coro/detail/InlineTask.h>
 #include <folly/executors/InlineExecutor.h>
 #include <folly/executors/ManualExecutor.h>
@@ -39,6 +39,31 @@
 
 using namespace folly;
 
+constexpr bool check_for_size_regressions() {
+  namespace detail = folly::coro::detail;
+
+  static_assert(sizeof(coro::Task<>) == sizeof(void*));
+  static_assert(sizeof(coro::Task<int>) == sizeof(void*));
+
+  // Prevent size regressions due to member or base ordering
+  constexpr size_t promiseSize =
+      // From TaskPromiseBase:
+      sizeof(coro::ExtendedCoroutineHandle) + sizeof(folly::AsyncStackFrame) +
+      sizeof(folly::Executor::KeepAlive<>) + sizeof(folly::CancellationToken) +
+      sizeof(coro::coroutine_handle<detail::ScopeExitTaskPromiseBase>) +
+      // hasCancelTokenOverride_ and bypassExceptionThrowing_ should pack into
+      sizeof(void*) +
+      // From TaskPromiseCrtpBase:
+      sizeof(Try<int>) +
+      // From ExtendedCoroutinePromiseCrtp:
+      sizeof(coro::ExtendedCoroutineHandle::PromiseBase);
+  static_assert(sizeof(detail::TaskPromise<void>) == promiseSize);
+  static_assert(sizeof(detail::TaskPromise<int>) == promiseSize);
+
+  return true;
+}
+static_assert(check_for_size_regressions());
+
 static_assert( //
     std::is_same<
         folly::coro::semi_await_result_t<folly::coro::Task<void>>,
@@ -350,17 +375,19 @@ TEST_F(TaskTest, FutureTailCall) {
 
 TEST_F(TaskTest, FutureRoundtrip) {
   folly::coro::blockingWait([]() -> folly::coro::Task<void> {
-    co_yield folly::coro::co_result(co_await folly::coro::co_awaitTry(
-        []() -> folly::coro::Task<void> { co_return; }().semi()));
+    co_yield folly::coro::co_result(
+        co_await folly::coro::co_awaitTry(
+            []() -> folly::coro::Task<void> { co_return; }().semi()));
   }());
 
   EXPECT_THROW(
       folly::coro::blockingWait([]() -> folly::coro::Task<void> {
-        co_yield folly::coro::co_result(co_await folly::coro::co_awaitTry(
-            []() -> folly::coro::Task<void> {
-              co_yield folly::coro::co_error(std::runtime_error(""));
-            }()
-                        .semi()));
+        co_yield folly::coro::co_result(
+            co_await folly::coro::co_awaitTry(
+                []() -> folly::coro::Task<void> {
+                  co_yield folly::coro::co_error(std::runtime_error(""));
+                }()
+                            .semi()));
       }()),
       std::runtime_error);
 }
@@ -412,7 +439,7 @@ TEST_F(TaskTest, TaskOfLvalueReferenceAsResult) {
     };
 
     int value = 123;
-    auto&& res = co_await co_await_result(returnIntRef(value));
+    auto&& res = co_await value_or_error_or_stopped(returnIntRef(value));
     CHECK(res.has_value());
     CHECK_EQ(&value, &res.value_or_throw());
     CHECK_EQ(&value, &(co_await folly::or_unwind(std::move(res))));
@@ -450,8 +477,8 @@ TEST_F(TaskTest, CancellationPropagation) {
 
 TEST_F(TaskTest, CancellationPropagatesThroughCoAwaitTry) {
   folly::CancellationSource source;
-  folly::Try<int> result =
-      folly::coro::blockingWait(folly::coro::co_withCancellation(
+  folly::Try<int> result = folly::coro::blockingWait(
+      folly::coro::co_withCancellation(
           source.getToken(),
           folly::coro::co_awaitTry([&]() -> folly::coro::Task<int> {
             auto cancelToken =
@@ -563,17 +590,21 @@ TEST_F(TaskTest, MakeTask) {
     co_await folly::coro::makeTask();
     co_await folly::coro::makeTask(folly::unit);
 
-    auto err = co_await co_awaitTry(folly::coro::makeErrorTask<int>(
-        folly::make_exception_wrapper<std::runtime_error>("")));
+    auto err = co_await co_awaitTry(
+        folly::coro::makeErrorTask<int>(
+            folly::make_exception_wrapper<std::runtime_error>("")));
     EXPECT_TRUE(err.hasException());
 
-    err = co_await co_awaitTry(folly::coro::makeResultTask(folly::Try<int>(
-        folly::make_exception_wrapper<std::runtime_error>(""))));
+    err = co_await co_awaitTry(
+        folly::coro::makeResultTask(
+            folly::Try<int>(
+                folly::make_exception_wrapper<std::runtime_error>(""))));
     EXPECT_TRUE(err.hasException());
 
     auto try1 = co_await co_awaitTry(
-        folly::coro::makeResultTask(folly::Try<folly::Unit>(
-            folly::make_exception_wrapper<std::runtime_error>(""))));
+        folly::coro::makeResultTask(
+            folly::Try<folly::Unit>(
+                folly::make_exception_wrapper<std::runtime_error>(""))));
     EXPECT_TRUE(try1.hasException());
     try1 = co_await co_awaitTry(
         folly::coro::makeResultTask(folly::Try<folly::Unit>(folly::unit)));
@@ -643,8 +674,8 @@ TEST_F(TaskTest, CoAwaitTryWithScheduleOnAndCancellation) {
     cancelSrc = {};
 
     {
-      folly::Try<int> result =
-          co_await folly::coro::co_awaitTry(folly::coro::co_withCancellation(
+      folly::Try<int> result = co_await folly::coro::co_awaitTry(
+          folly::coro::co_withCancellation(
               cancelSrc.getToken(),
               co_withExecutor(folly::getGlobalCPUExecutor(), makeTask())));
       EXPECT_EQ(42, result.value());
