@@ -41,7 +41,7 @@ std::atomic_bool loggedMessage{false};
 // the stack frames to use.
 template <typename ExceptionMetaFunc>
 ExceptionInfo getTraceWithFunc(
-    const std::exception& ex, ExceptionMetaFunc func) {
+    void* ex, const std::type_info* typeInfo, ExceptionMetaFunc func) {
   if (!detail::isSmartExceptionTracerHookEnabled() &&
       !loggedMessage.load(std::memory_order_relaxed)) {
     LOG(WARNING)
@@ -50,57 +50,49 @@ ExceptionInfo getTraceWithFunc(
   }
 
   ExceptionInfo info;
-  info.type = &typeid(ex);
-  auto rlockedMeta = detail::getMetaMap().withRLock(
-      [&](const auto& locked) noexcept
-      -> detail::SynchronizedExceptionMeta::RLockedPtr {
-        auto* meta = get_ptr(locked, (void*)&ex);
-        // If we can't find the exception, return an empty stack trace.
-        if (!meta) {
-          return {};
-        }
-        CHECK(*meta);
-        // Acquire the meta rlock while holding the map's rlock, to block meta's
-        // destruction.
-        return (*meta)->rlock();
-      });
+  info.type = typeInfo;
 
-  if (!rlockedMeta) {
-    return info;
+  if (auto meta = get_default(*detail::getMetaMap().rlock(), ex)) {
+    auto [traceBeginIt, traceEndIt] = func(*meta);
+    info.frames.assign(traceBeginIt, traceEndIt);
   }
 
-  auto [traceBeginIt, traceEndIt] = func(*rlockedMeta);
-  info.frames.assign(traceBeginIt, traceEndIt);
   return info;
 }
 
 template <typename ExceptionMetaFunc>
 ExceptionInfo getTraceWithFunc(
     const std::exception_ptr& ptr, ExceptionMetaFunc func) {
-  if (auto* ex = folly::exception_ptr_get_object<std::exception>(ptr)) {
-    return getTraceWithFunc(*ex, std::move(func));
+  if (auto ex = folly::exception_ptr_get_object(ptr, nullptr)) {
+    return getTraceWithFunc(
+        ex, folly::exception_ptr_get_type(ptr), std::move(func));
   }
   return ExceptionInfo();
 }
 
+template <typename ExceptionMetaFunc>
+ExceptionInfo getTraceWithFunc(
+    const std::exception& e, ExceptionMetaFunc func) {
+  return getTraceWithFunc(
+      const_cast<void*>(dynamic_cast<const void*>(&e)),
+      &typeid(e),
+      std::move(func));
+}
+
 template <typename ExceptionMetaFunc>
 ExceptionInfo getTraceWithFunc(
     const exception_wrapper& ew, ExceptionMetaFunc func) {
-  if (auto* ex = ew.get_exception()) {
-    return getTraceWithFunc(*ex, std::move(func));
-  }
-  return ExceptionInfo();
+  return getTraceWithFunc(ew.exception_ptr(), std::move(func));
 }
 
 auto getAsyncStackTraceItPair(const detail::ExceptionMeta& meta) {
-  return std::make_pair(
-      meta.traceAsync.addresses,
-      meta.traceAsync.addresses + meta.traceAsync.frameCount);
+  auto addr = meta.traceAsync.addresses;
+  return std::pair(addr, addr + meta.traceAsync.frameCount);
 }
 
 auto getNormalStackTraceItPair(const detail::ExceptionMeta& meta) {
-  return std::make_pair(
-      meta.trace.addresses, meta.trace.addresses + meta.trace.frameCount);
+  auto addr = meta.trace.addresses;
+  return std::pair(addr, addr + meta.trace.frameCount);
 }
 
 } // namespace
