@@ -215,7 +215,9 @@ TEST(Future, lacksPreconditionValid) {
 #define DOIT(STMT)         \
   do {                     \
     auto f = makeValid();  \
-    { STMT; }              \
+    {                      \
+      STMT;                \
+    }                      \
     copy(std::move(f));    \
     EXPECT_NO_THROW(STMT); \
   } while (false)
@@ -349,10 +351,10 @@ TEST(Future, hasPostconditionInvalid) {
 }
 
 namespace {
-Future<int> thenErrorHelperEggs(eggs_t&&) {
+Future<int> thenErrorHelperEggs(const eggs_t&) {
   return makeFuture(10);
 }
-Future<int> thenErrorHelperGeneric(std::exception&&) {
+Future<int> thenErrorHelperGeneric(const std::exception&) {
   return makeFuture(20);
 }
 Future<int> thenErrorHelperWrapper(folly::exception_wrapper&&) {
