@@ -15,10 +15,12 @@
  */
 
 use std::os::raw::c_void;
+use std::slice;
 
 use bytes::Buf;
 use bytes::Bytes;
 use cxx::UniquePtr;
+#[cfg(fbcode_build)]
 use fbthrift::BufExt;
 use iobuf_sys::root::facebook::rust::*;
 use iobuf_sys::root::folly::IOBuf as IOBufSys;
@@ -87,6 +89,10 @@ impl IOBufShared {
         IOBufCursor::from(self)
     }
 
+    // This is internal-only to avoid external folly depending on fbthrift,
+    // that complicates build. A potentially long-term fix might be moving
+    // BufExt to a small, shared, and published crate.
+    #[cfg(fbcode_build)]
     /// Converts a `BufExt` into a potentially chained `IOBufShared`. Whether
     /// this conversion copies is dependent on whether
     /// `BufExt::copy_or_reuse_bytes` copies.
@@ -235,7 +241,26 @@ impl From<IOBufShared> for Vec<u8> {
 
 impl From<IOBufShared> for Bytes {
     fn from(iob: IOBufShared) -> Self {
-        Bytes::from(Vec::from(iob))
+        struct ContiguousUnshared(IOBufShared);
+
+        impl AsRef<[u8]> for ContiguousUnshared {
+            fn as_ref(&self) -> &[u8] {
+                unsafe { slice::from_raw_parts(self.0.0.data(), self.0.0.length()) }
+            }
+        }
+
+        if iob.0.isChained() || iob.0.isSharedOne() {
+            // If there is more than one buffer in the chain, coalesce their
+            // contents into a Vec. If there is only one buffer but our IOBuf is
+            // not the unique owner, also copy to Vec.
+            //
+            // The conversion from Vec<u8> to Bytes does not allocate.
+            Bytes::from(Vec::from(iob))
+        } else {
+            // Fast path: do not copy buffer contents. This makes one small
+            // (3-word) allocation only.
+            Bytes::from_owner(ContiguousUnshared(iob))
+        }
     }
 }
 
@@ -262,8 +287,9 @@ impl PartialEq for IOBufShared {
     }
 }
 
+#[cfg(fbcode_build)]
 #[cfg(test)]
-mod test {
+mod bufext_test {
     use super::*;
 
     /// An iobuf created from an empty buffer should also be empty.
