@@ -415,6 +415,7 @@ TEST(Settings, basic) {
       follytest/public_flag_to_a/int/456/Public flag to a/300/from_string
       follytest/public_flag_to_b/std::string/"basdf"/Public flag to b/basdf/default
       follytest/some_flag/std::string/"default"/Description/default/default
+      follytest/some_unused_flag/std::string/"default"/Description/default/default
       follytest/trivial_user_defined/TrivialUserDefinedType/TrivialUserDefinedType{123}/Trivial user defined type/123/default
       follytest/unused/std::string/"unused_default"/Not used, but should still be in the list/unused_default/default
       follytest/user_defined/UserDefinedType/"b"/User defined type constructed from string/b_out/default
@@ -678,22 +679,49 @@ TEST(SettingsTest, callback) {
 TEST(SettingsTest, observers) {
   auto observer = folly::settings::getObserver(
       some_ns::FOLLY_SETTING(follytest, some_flag));
+  EXPECT_EQ(observer.getCreatorName(), "FOLLY_SETTING_follytest_some_flag");
+  size_t callbackCount = 0;
   std::string updatedFromCallback;
   auto callbackHandle = observer.addCallback([&](auto snapshot) {
+    ++callbackCount;
     updatedFromCallback = *snapshot;
   });
   EXPECT_EQ(**observer, "default");
   EXPECT_EQ(updatedFromCallback, "default");
-
+  EXPECT_EQ(callbackCount, 1);
   some_ns::FOLLY_SETTING(follytest, some_flag).set("new value");
   folly::observer_detail::ObserverManager::waitForAllUpdates();
   EXPECT_EQ(**observer, "new value");
   EXPECT_EQ(updatedFromCallback, "new value");
+  EXPECT_EQ(callbackCount, 2);
+  // Check that the callback is not invoked if set to the same value
+  some_ns::FOLLY_SETTING(follytest, some_flag).set("new value");
+  folly::observer_detail::ObserverManager::waitForAllUpdates();
+  EXPECT_EQ(callbackCount, 2);
 
   folly::settings::Snapshot snapshot;
   snapshot.forEachSetting([](const auto& s) {
     EXPECT_EQ(s.hasHadCallbacks(), s.fullName() == "follytest_some_flag");
   });
+  // Check we can create an observer for a custom setting type that doesn't
+  // implement operator==
+  some_ns::FOLLY_SETTING(follytest, user_defined_with_meta).observer();
+}
+
+TEST(SettingsTest, accessWithObserver) {
+  auto observer1 = folly::observer::makeObserver([]() {
+    return *some_ns::FOLLY_SETTING(follytest, some_flag);
+  });
+  auto observer2 = folly::observer::makeObserver([]() {
+    return some_ns::FOLLY_SETTING(follytest, some_flag)
+        .valueRegisterObserverDependency();
+  });
+  ASSERT_EQ(**observer1, "default");
+  ASSERT_EQ(**observer2, "default");
+  some_ns::FOLLY_SETTING(follytest, some_flag).set("new value");
+  folly::observer_detail::ObserverManager::waitForAllUpdates();
+  EXPECT_EQ(**observer1, "default");
+  EXPECT_EQ(**observer2, "new value");
 }
 
 TEST(Settings, immutables) {
