@@ -574,7 +574,6 @@ void combineWithLockTryAndTimedNThreads(
 
   auto tryLockFunction = [&]() {
     while (!stop.load()) {
-      using Mutex = std::decay_t<decltype(mutex)>;
       auto lck = std::unique_lock{mutex, std::defer_lock};
       if (lck.try_lock()) {
         EXPECT_EQ(barrier.fetch_add(1, std::memory_order_relaxed), 0);
@@ -586,7 +585,6 @@ void combineWithLockTryAndTimedNThreads(
 
   auto timedLockFunction = [&]() {
     while (!stop.load()) {
-      using Mutex = std::decay_t<decltype(mutex)>;
       auto lck = std::unique_lock{mutex, std::defer_lock};
       if (lck.try_lock_for(kForever)) {
         EXPECT_EQ(barrier.fetch_add(1, std::memory_order_relaxed), 0);
@@ -1820,6 +1818,8 @@ TEST(DistributedMutex, TestExceptionPropagationUncontended) {
   thread.join();
 }
 
+#if !defined(FOLLY_SANITIZE_THREAD) || !FOLLY_SANITIZE_THREAD
+
 namespace {
 template <template <typename> class Atom = std::atomic>
 void concurrentExceptionPropagationStress(
@@ -1839,7 +1839,6 @@ void concurrentExceptionPropagationStress(
   //
   // So we are disabling it for now until some point in the future where TSAN
   // stops reporting this as a false-positive.
-  SKIP_IF(folly::kIsSanitizeThread);
 
   TestConstruction::reset();
   auto&& mutex = detail::distributed_mutex::DistributedMutex<Atom>{};
@@ -1952,6 +1951,8 @@ TEST(DistributedMutex, TestExceptionPropagationDeterministicSixtyFourThreads) {
       64, std::chrono::seconds{kStressTestSeconds});
 }
 
+#endif // !FOLLY_SANITIZE_THREAD
+
 namespace {
 std::array<std::uint64_t, 8> makeMonotonicArray(int start) {
   auto array = std::array<std::uint64_t, 8>{};
